netapp_ontap.models.snapmirror_relationship_transfer API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snapmirror_relationship_transfer`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnapmirrorRelationshipTransferSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapmirrorRelationshipTransfer object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `bytes_transferred GET POST PATCH`

    Bytes transferred.

  `links GET`

    The links field of the snapmirror_relationship_transfer.

  `state GET POST PATCH`

    The state field of the snapmirror_relationship_transfer.

    Valid choices:

    - aborted
    - failed
    - hard_aborted
    - queued
    - success
    - transferring
  `uuid GET POST PATCH`

    The uuid field of the snapmirror_relationship_transfer.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412